==> nextcloud-29.0.5.tgz: nextcloud/apps/suspicious_login/l10n/sk.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Zistené nová lokalita prihlásenia",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Zistilo sa podozrivé prihlásenie do vášho účtu. Adresa IP %s bola klasifikovaná ako podozrivá. Ak ste to boli vy, môžete toto hlásenie ignorovať. V opačnom prípade odporúčame, aby ste si zmenili svoje heslo.",
    "Suspicious Login" : "Podozrivé prihlasovanie",
    "New login detected" : "Zistené nové prihlásenie",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Upozornovať na podozrivé adresy IP prihlasujúce sa do systému Nextcloud\n\t",
    "Suspicious login detection" : "Zisťovanie podozrivého prihlasovania",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "V tejto inštancii systému Nextcloud je povolená apka Podozrivé prihlasovanie. Bude sledovať adresy IP používateľov, ktorí sa úspešne prihlásia a zostavovať klasifikátor, ktorý bude varovať v prípade, ak dané prihlásenie bude prichádzať z podozrivej adresy IP.",
    "Training data statistics" : "Trénovanie štatistických dát",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Doposiaľ aplikácia zaznamenala {total} prihlásení (vrátane klientskych pripojení), z ktorých {distinct} sú odlišné (IP, UID) n-tice.",
    "IPv4" : "Adresa IPv4",
    "IPv6" : "Adresa IPv6",
    "Classifier model statistics" : "Štatistiky klasifikačného modelu",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Zatiaľ nebol natrénovaný žiadny model klasifikátora. To s najväčšou pravdepodobnosťou znamená, že ste apku povolili len nedávno. Pretože správne natrénovanie modelu vyžaduje viac údajov, apka bude čakať, kým sa nezaznamenajú prihlásenia aspoň za {days} dní.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Počas vyhodnocovania najnovší model (v činnosti {time}) zachytil {recall}% všetkých podozrivých prihlásení (zrušenie), zatiaľ čo {precision}% prihlásení klasifikovaných ako podozrivé sú skutočne podozrivé (presnosť). Nižšie vidíte vizualizáciu výkonu historického modelu.",
    "Precision" : "Presnosť",
    "Recall" : "Vyvolať",
    "More information ↗" : "Viac informácií ↗",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Viac informácií získate stlačením tlačidla, ktoré otvorí %s a zobrazí informácie o podozrivej adrese IP."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-30.0.15.tgz: nextcloud/apps/suspicious_login/l10n/sk.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Zistené nová lokalita prihlásenia",
    "More info about the suspicious IP address available on %s" : "Viac informácií o podozrivej IP adrese nájdete na %s",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Zistilo sa podozrivé prihlásenie do vášho účtu. Adresa IP %s bola klasifikovaná ako podozrivá. Ak ste to boli vy, môžete toto hlásenie ignorovať. V opačnom prípade odporúčame, aby ste si zmenili svoje heslo.",
    "Open %s ↗" : "Otvoriť %s ↗",
    "Suspicious Login" : "Podozrivé prihlasovanie",
    "New login detected" : "Zistené nové prihlásenie",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Upozornovať na podozrivé adresy IP prihlasujúce sa do systému Nextcloud\n\t",
    "Suspicious login detection" : "Zisťovanie podozrivého prihlasovania",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "V tejto inštancii systému Nextcloud je povolená apka Podozrivé prihlasovanie. Bude sledovať adresy IP používateľov, ktorí sa úspešne prihlásia a zostavovať klasifikátor, ktorý bude varovať v prípade, ak dané prihlásenie bude prichádzať z podozrivej adresy IP.",
    "Training data statistics" : "Trénovanie štatistických dát",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Doposiaľ aplikácia zaznamenala {total} prihlásení (vrátane klientskych pripojení), z ktorých {distinct} sú odlišné (IP, UID) n-tice.",
    "IPv4" : "Adresa IPv4",
    "IPv6" : "Adresa IPv6",
    "Classifier model statistics" : "Štatistiky klasifikačného modelu",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Zatiaľ nebol natrénovaný žiadny model klasifikátora. To s najväčšou pravdepodobnosťou znamená, že ste apku povolili len nedávno. Pretože správne natrénovanie modelu vyžaduje viac údajov, apka bude čakať, kým sa nezaznamenajú prihlásenia aspoň za {days} dní.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Počas vyhodnocovania najnovší model (v činnosti {time}) zachytil {recall}% všetkých podozrivých prihlásení (zrušenie), zatiaľ čo {precision}% prihlásení klasifikovaných ako podozrivé sú skutočne podozrivé (presnosť). Nižšie vidíte vizualizáciu výkonu historického modelu.",
    "Precision" : "Presnosť",
    "Recall" : "Vyvolať"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
